@@ -3,7 +3,6 @@
 import logging
 logger = logging.getLogger(__name__)
 
-import time
 import json
 
 from django.http import HttpResponse
@@ -16,7 +15,7 @@ from django.utils.decorators import method_decorator
 
 from ..utils import log
 from ..main.models import Host
-from ..main.dnstools import update, SameIpError, DnsUpdateError, NameServerNotAvailable, check_ip
+from ..main.dnstools import update, SameIpError, DnsUpdateError, NameServerNotAvailable, check_ip, put_ip_into_session
 
 
 def Response(content):
@@ -60,11 +59,10 @@ class DetectIpView(View):
         # the sessionid:
         s = SessionStore(session_key=sessionid)
         ipaddr = request.META['REMOTE_ADDR']
-        key = check_ip(ipaddr)
-        s[key] = ipaddr
-        s[key + '_timestamp'] = int(time.time())
-        logger.debug("detected remote %s address: %s for session %s" % (key, ipaddr, sessionid))
-        s.save()
+        # as this is NOT the session automatically established and
+        # also saved by the framework, we need to use save=True here
+        put_ip_into_session(s, ipaddr, save=True)
+        logger.debug("detected remote address: %s for session %s" % (ipaddr, sessionid))
         return HttpResponse(status=204)
 
 
@@ -182,13 +180,11 @@ class NicUpdateView(View):
         :param request: django request object
         :return: HttpResponse object
         """
-        ssl = request.is_secure()
         hostname = request.GET.get('hostname')
-        agent = request.META.get('HTTP_USER_AGENT', 'unknown')
         auth = request.META.get('HTTP_AUTHORIZATION')
         if auth is None:
             logger.warning('%s - received no auth' % (hostname, ))
-            return basic_challenge("authenticate to update DNS", 'noauth')
+            return basic_challenge("authenticate to update DNS", 'badauth')
         username, password = basic_authenticate(auth)
         if not check_api_auth(username, password):
             logger.warning('%s - received bad credentials, username: %s' % (hostname, username, ))
@@ -202,12 +198,14 @@ class NicUpdateView(View):
             logger.warning("rejecting to update wrong host %s (given in query string) "
                            "[instead of %s (given in basic auth)]" % (hostname, username))
             return Response('nohost')  # or 'badauth'?
-        ipaddr = request.GET.get('myip')
-        if ipaddr is None:
-            ipaddr = request.META.get('REMOTE_ADDR')
+        agent = request.META.get('HTTP_USER_AGENT', 'unknown')
         if agent in settings.BAD_AGENTS:
             logger.warning('%s - received update from bad user agent' % (hostname, ))
             return Response('badagent')
+        ipaddr = request.GET.get('myip')
+        if ipaddr is None:
+            ipaddr = request.META.get('REMOTE_ADDR')
+        ssl = request.is_secure()
         return _update(hostname, ipaddr, agent, ssl, logger=logger)
 
 
@@ -230,8 +228,6 @@ class AuthorizedNicUpdateView(View):
         :param request: django request object
         :return: HttpResponse object
         """
-        ssl = request.is_secure()
-        agent = request.META.get('HTTP_USER_AGENT', 'unknown')
         hostname = request.GET.get('hostname')
         if hostname is None:
             return Response('nohost')
@@ -240,8 +236,10 @@ class AuthorizedNicUpdateView(View):
             return Response('nohost')
         logger.info("authenticated by session as user %s, creator of host %s" % (request.user.username, hostname))
         ipaddr = request.GET.get('myip')
-        if not ipaddr:
+        if not ipaddr:  # None or emptry string
             ipaddr = request.META.get('REMOTE_ADDR')
+        ssl = request.is_secure()
+        agent = request.META.get('HTTP_USER_AGENT', 'unknown')
         return _update(hostname, ipaddr, agent, ssl, logger=logger)
 
 
